@@ -1,48 +1,45 @@
-'use strict'
 const t = require('tap')
-const path = require('path')
-const pkg = path.resolve(__dirname, path.basename(__filename, '.js'))
 
-require('./pkgtree.js')(pkg, {
+const pkg = require('./pkgtree')(t, {
   $package: {
     name: 'a',
     version: '1.2.3',
     dependencies: {
       b: '1.2.3',
-      d: '1.2.3'
+      d: '1.2.3',
     },
-    bundledDependencies: [ 'b' ]
+    bundledDependencies: ['b'],
   },
   b: {
     d: { $package: {
       name: 'd',
       version: '1.2.3',
       dependencies: {
-        e: '1.2.3'
-      }
-    }},
+        e: '1.2.3',
+      },
+    } },
     $package: {
       name: 'b',
       version: '1.2.3',
       dependencies: {
         c: '1.2.3',
-        d: '1.2.3'
-      }
-    }
+        d: '1.2.3',
+      },
+    },
   },
   c: { $package: {
     name: 'c',
-    version: '1.2.3'
-  }},
+    version: '1.2.3',
+  } },
   d: { $package: {
     name: 'd',
     version: '1.2.3',
     dependencies: {
-      c: '1.2.3'
-    }
-  }},
-  e: {}
-}, t)
+      c: '1.2.3',
+    },
+  } },
+  e: {},
+})
 
 const walk = require('../')
 
@@ -51,5 +48,5 @@ const check = (result, t) => {
   t.end()
 }
 
-t.test('sync', t => check(walk.sync({path: pkg}), t))
-t.test('async', t => walk({path: pkg}).then(res => check(res, t)))
+t.test('sync', t => check(walk.sync({ path: pkg }), t))
+t.test('async', t => walk({ path: pkg }).then(res => check(res, t)))
