@@ -1,9 +1,6 @@
-'use strict'
 const t = require('tap')
-const path = require('path')
-const pkg = path.resolve(__dirname, path.basename(__filename, '.js'))
 
-require('./pkgtree.js')(pkg, {
+const pkg = require('./pkgtree')(t, {
   $package: {
     name: '@a/a',
     version: '1.2.3',
@@ -11,43 +8,43 @@ require('./pkgtree.js')(pkg, {
       '@x/b': '1.2.3',
       '@y/d': '1.2.3',
       '@weird/asdf': '1.2.3',
-      '@missing/scope': '1.2.3'
+      '@missing/scope': '1.2.3',
     },
-    bundleDependencies: [ '@x/b', '@weird/asdf', '@missing/scope' ]
+    bundleDependencies: ['@x/b', '@weird/asdf', '@missing/scope'],
   },
   '@x/b': {
     '@y/d': { $package: {
       name: '@y/d',
       version: '1.2.3',
       dependencies: {
-        e: '1.2.3'
-      }
-    }},
+        e: '1.2.3',
+      },
+    } },
     $package: {
       name: '@x/b',
       version: '1.2.3',
       dependencies: {
         '@q/c': '1.2.3',
-        '@y/d': '1.2.3'
-      }
-    }
+        '@y/d': '1.2.3',
+      },
+    },
   },
   '@q/c': { $package: {
     name: '@q/c',
-    version: '1.2.3'
-  }},
+    version: '1.2.3',
+  } },
   '@y/d': { $package: {
     name: '@y/d',
     version: '1.2.3',
     dependencies: {
-      '@q/c': '1.2.3'
-    }
-  }},
+      '@q/c': '1.2.3',
+    },
+  } },
   e: { $package: {
     name: 'e',
-    version: '1.2.3'
-  }}
-}, t)
+    version: '1.2.3',
+  } },
+})
 
 // put a weird not-package thing in a node_modules @-scope "folder"
 const fs = require('fs')
@@ -61,5 +58,5 @@ const check = (result, t) => {
   t.end()
 }
 
-t.test('sync', t => check(walk.sync({path: pkg}), t))
-t.test('async', t => walk({path: pkg}).then(res => check(res, t)))
+t.test('sync', t => check(walk.sync({ path: pkg }), t))
+t.test('async', t => walk({ path: pkg }).then(res => check(res, t)))
